Module: Postmark

Defined in:
lib/postmark/spam_check/client.rb,
lib/postmark/spam_check.rb,
lib/postmark/spam_check/report.rb,
lib/postmark/spam_check/version.rb

Overview

The Client is responsible for making requests to the remote API. It doesn’t know about the format of the results, only that it is JSON and passes the parsed result to the Report, which will handle the rest.

Defined Under Namespace

Modules: SpamCheck